<?php if ( ! defined('BASEPATH')) exit('No direct script access allowed');

class Admin extends CI_Controller {

	public function __construct()
	{
		parent::__construct();
		$this->load->library('session');
		$this->load->model('consultor_model');
		$this->load->helper('url');
		$this->load->helper('file');
		$this->load->helper('download');
		$this->load->library('pagination');
	}

	public function index()
	{
		redirect('admin/dashboard');
	}

	public function dashboard()
	{
		$data = array(
			'consultor_nombres' => $this->session->userdata('consultor_nombres'),
			);
		$query=$this->consultor_model->count_usuarios();
		$data['total']=sizeof($query);

		$this->load_header('administrador', $data, 'Dashboard');
		$this->load->view('abogado/admin/admin-dashboard', $data);
		$this->load->view('templates/footer', $data);

	}

	public function abogados($orderby = NULL, $page = NULL)
	{
		if (is_null($orderby)) {
			redirect('admin/abogados/nombre-asc');
		}

		$data = array(
			'consultor_nombres' => $this->session->userdata('consultor_nombres'),
			);

		$data['orderby'] = $orderby;

		// Paginación
		$config = $this->pagination_config();
		$config['base_url'] = site_url('admin/abogados/'.$orderby);
		$config['total_rows'] = $this->db->count_all('lista_abogados');
		$config['per_page'] = "10";
		$config["uri_segment"] = 4;
		$choice = $config["total_rows"] / $config["per_page"];
		$config["num_links"] = floor($choice);
		$data['page'] = ($this->uri->segment(4)) ? $this->uri->segment(4) : 0;
		$this->pagination->initialize($config);
		$data['pagination'] = $this->pagination->create_links();

		$data['lista_abogados'] = $this->consultor_model->lista_abogados($orderby, $config['per_page'], $data['page']);

		$data['page_scripts'][] = 'admin.js';
		
		$this->load_header('administrador', $data, 'Abogados');
		$this->load->view('abogado/admin/admin-users', $data);
		$this->load->view('templates/footer', $data);
	}

	public function backup(){
		$data = array(
			'consultor_nombres' => $this->session->userdata('consultor_nombres'),
			);
		$this->load_header('administrador', $data, 'backup');
		$this->load->view('abogado/admin/admin-backup',$data);
		$this->load->view('templates/footer',$data);

	}

	public function backup_db(){
		//carga la clase dbutil
		$this->load->dbutil();

		$prefs=array(
			//'tables' => array('abogados','casos','clientes','consultas'),
			'format' => 'sql',
			'filename' => 'ata.sql',
			//'add_insert' => TRUE
		 );
		//copia de seguridad de la bd y se asigna a una variable
		$backup =& $this->dbutil->backup($prefs);
		$db_name = 'backup-ata-'. date("Y-m-d-H-i-s").'.sql';
		$save = '/upload/_tmp/'.$db_name;
		write_file($save,$backup);
		force_download($db_name,$backup);

	}

		function load_header($active_tab = 'inicio', $data = array(), $active_page = 'Acceso'){
		$data['tab_admin'] = TRUE;

		$data['active_page'] = $active_page;
		$this->load->view('templates/header', $data);
	}

		function pagination_config(){
		$config['full_tag_open'] = '<ul class="pagination" style="margin-top:4px; margin-bottom:0">';
		$config['full_tag_close'] = '</ul>';
		$config['first_link'] = false;
		$config['last_link'] = false;
		$config['first_tag_open'] = '<li>';
		$config['first_tag_close'] = '</li>';
		$config['prev_link'] = '&laquo';
		$config['prev_tag_open'] = '<li class="prev">';
		$config['prev_tag_close'] = '</li>';
		$config['next_link'] = '&raquo';
		$config['next_tag_open'] = '<li>';
		$config['next_tag_close'] = '</li>';
		$config['last_tag_open'] = '<li>';
		$config['last_tag_close'] = '</li>';
		$config['cur_tag_open'] = '<li class="active"><a href="#">';
		$config['cur_tag_close'] = '</a></li>';
		$config['num_tag_open'] = '<li>';
		$config['num_tag_close'] = '</li>';

		return $config;
	}

	public function get_abogado()
	{
		if($this->input->is_ajax_request()){
			$idabogado = $this->input->post('abogado', TRUE);
			$abogado = $this->consultor_model->abogado_info($idabogado);
			echo json_encode($abogado);
		}
	}

	public function set_abogado()
	{
		if (!$this->input->is_ajax_request()) {
			die();
		}

		$persona = $this->input->post(array('idpersona', 'nombres', 'apellidop', 'apellidom', 'correo', 'password'));

		$abogado = $this->input->post(array('idabogado', 'cedula'));

		$nuevo = empty($abogado['idabogado']) && empty($persona['idpersona']);
		$editar = !empty($abogado['idabogado']) && !empty($persona['idpersona']);

		if ($nuevo) {
			$result = $this->consultor_model->nuevo_abogado($persona, $abogado);
		} elseif ($editar) {
			$result = $this->consultor_model->editar_abogado($persona, $abogado);
		}

		echo json_encode(array('status' => ($result) ? 'ok' : 'error'));
	}

	public function bitacora_carga_datos(){
		$data = array(
			'consultor_nombres' => $this->session->userdata('consultor_nombres'),
			);
		$data['page_scripts'] = array('ajax.js', 'editarcliente.js');

		$config = $this->pagination_config();
		$config['base_url'] = site_url('admin/bitacora_carga_datos');
		$config['total_rows'] = $this->db->count_all('textos');
		$config['per_page'] = "10";
		$config["uri_segment"] = 4;
		$choice = $config["total_rows"] / $config["per_page"];
		$config["num_links"] = floor($choice);

		$this->pagination->initialize($config);
		$data['page'] = ($this->uri->segment(4)) ? $this->uri->segment(4) : 0;

		$data['result']=$this->consultor_model->bitacora_carga_datos($data['page'], $config["per_page"]);
		$data['pagination'] = $this->pagination->create_links();
		
		$this->load_header('administrador', $data, 'bitacora_carga_datos');
		$this->load->view('abogado/admin/bitacora-carga-datos',$data);
		$this->load->view('templates/footer',$data);
	}

	public function count_usuarios(){
		// $query=$this->consultor_model->count_usuarios();
		// $data['total']=sizeof($query);
		// die('<pre>'.print_r($data,1).'</pre>');
		// $this->load_header('administrador', $data, 'Dashboard');
		// $this->load->view('abogado/admin/admin-dashboard',$data);
		// $this->load->view('templates/footer',$data);

	}

}

/* End of file Admin.php */
/* Location: ./application/controllers/Admin.php */